Utils (pylira.utils)
====================
This subpackage contains utility functionality.

.. warning::
    The functionality in `pylira.utils` is not considered as public API and might be
    subject to changes and not stable.

Plotting (pylira.utils.plot)
----------------------------
.. automodapi:: pylira.utils.plot
    :no-heading:
    :no-inheritance-diagram:
    :include-all-objects:


I/O (pylira.utils.io)
---------------------
.. automodapi:: pylira.utils.io
    :no-heading:
    :no-inheritance-diagram:
    :include-all-objects:
